@@ -2,6 +2,7 @@ package cmd
 
 import (
 	"context"
+	"os"
 	"strings"
 	"testing"
 
@@ -29,13 +30,23 @@ func createPluginCmd() *pluginTemplateCmd {
 	return pluginCmd
 }
 
+// TestFlagsArePassedAsArgs ensures that the plugin is passing all args and flags as expected.
+// This is a complex dance between the CLI itself and the plugin, so the flags come from
+// two different sources as a result. This test is here to catch any non-obvious regressions
 func TestFlagsArePassedAsArgs(t *testing.T) {
-	Execute(context.Background())
-
 	pluginCmd := createPluginCmd()
 	rootCmd.AddCommand(pluginCmd.cmd)
-	executeCommandC(rootCmd, "test", "testarg", "--testflag")
 
-	require.Equal(t, len(pluginCmd.ParsedArgs), 2)
-	require.Equal(t, strings.Join(pluginCmd.ParsedArgs, " "), "testarg --testflag")
+	Execute(context.Background())
+
+	// temp override for the os.Args so that the pluginCmd can use them
+	oldArgs := os.Args
+	os.Args = []string{"stripe", "test", "testarg", "--log-level=info"}
+	defer func() { os.Args = oldArgs }()
+
+	rootCmd.SetArgs([]string{"test", "testarg", "--log-level=info"})
+	executeCommandC(rootCmd, "test", "testarg", "--log-level=info")
+
+	require.Equal(t, 2, len(pluginCmd.ParsedArgs))
+	require.Equal(t, "testarg --log-level=info", strings.Join(pluginCmd.ParsedArgs, " "))
 }
